@@ -558,8 +558,8 @@ private:
   void FilterCogSog(void);
 
   void ApplyGlobalColorSchemetoStatusBar(void);
-  void PostProcessNMEA(bool pos_valid, bool cog_sog_valid,
-                       const wxString &sfixtime);
+  void PostProcessNMEA(bool pos_valid, bool sog_valid,
+                       bool cog_valid, const wxString &sfixtime);
 
   bool ScrubGroupArray();
   wxString GetGroupName(int igroup);
