@@ -27,7 +27,7 @@
 
 #ifdef USE_ANDROID_GLES2
 
-#include <gl2.h>
+#include <GLES2/gl2.h>
 
 // Simple colored triangle shader
 
