@@ -92,6 +92,10 @@ const wxString AuthorText =
     wxT("      OpenCPN Lead Developer\n\n")
     wxT("    Pavel Kalian\n")
     wxT("      Packaging and PlugIn development\n\n")
+    wxT("    Håkan Svensson\n")
+    wxT("      Comms and Plugin integration\n\n")
+    wxT("    Rick Gleason\n")
+    wxT("      Plugin adaptation and maintenance\n\n")
     wxT("    Sean D'Epagnier\n")
     wxT("      OpenGL Architecture\n\n")
     wxT("    J.P. Joubert\n")
