@@ -1234,9 +1234,11 @@ void CanvasMenuHandler::PopupMenuHandler(wxCommandEvent &event) {
           g_pMarkInfoDialog->UpdateProperties();
         }
 
-        if (pRouteManagerDialog) {
-          if (pRouteManagerDialog->IsShown())
-            pRouteManagerDialog->UpdateWptListCtrl();
+        if(RouteManagerDialog::getInstanceFlag()){
+          if (pRouteManagerDialog) {
+            if (pRouteManagerDialog->IsShown())
+              pRouteManagerDialog->UpdateWptListCtrl();
+          }
         }
 
         gFrame->RefreshAllCanvas(false);
@@ -1438,8 +1440,10 @@ void CanvasMenuHandler::PopupMenuHandler(wxCommandEvent &event) {
 
         if (!g_pRouteMan->DeleteRoute(m_pSelectedRoute)) break;
 
-        if (pRouteManagerDialog && pRouteManagerDialog->IsShown())
-          pRouteManagerDialog->UpdateRouteListCtrl();
+        if(RouteManagerDialog::getInstanceFlag()){
+          if (pRouteManagerDialog && pRouteManagerDialog->IsShown())
+            pRouteManagerDialog->UpdateRouteListCtrl();
+        }
 
         if (g_pMarkInfoDialog && g_pMarkInfoDialog->IsShown()) {
           g_pMarkInfoDialog->ValidateMark();
@@ -1485,14 +1489,6 @@ void CanvasMenuHandler::PopupMenuHandler(wxCommandEvent &event) {
     case ID_RT_MENU_INSERT: {
       if (m_pSelectedRoute->m_bIsInLayer) break;
       bool rename = false;
-      int ask_return = OCPNMessageBox(
-          parent,
-          _("Waypoints can be renamed to include the new one, the names will "
-            "be '001', '002' etc.") +
-              _T("\n\n") + _("Do you want to rename the waypoints?"),
-          _("Rename Waypoints?"), wxYES_NO | wxCANCEL);
-      if (ask_return == wxID_YES) rename = true;
-
       m_pSelectedRoute->InsertPointAfter(m_pFoundRoutePoint, zlat, zlon,
                                          rename);
 
@@ -1677,9 +1673,11 @@ void CanvasMenuHandler::PopupMenuHandler(wxCommandEvent &event) {
             pRoutePropDialog->Hide();
         }
 
-        if (pRouteManagerDialog && pRouteManagerDialog->IsShown()) {
-          pRouteManagerDialog->UpdateWptListCtrl();
-          pRouteManagerDialog->UpdateRouteListCtrl();
+        if(RouteManagerDialog::getInstanceFlag()){
+          if (pRouteManagerDialog && pRouteManagerDialog->IsShown()) {
+            pRouteManagerDialog->UpdateWptListCtrl();
+            pRouteManagerDialog->UpdateRouteListCtrl();
+          }
         }
 
         gFrame->InvalidateAllGL();
