@@ -56,7 +56,7 @@
 #endif
 
 #ifdef USE_ANDROID_GLES2
-#include <gl2.h>
+#include <GLES2/gl2.h>
 #include "linmath.h"
 #endif
 
